@@ -1,10 +1,7 @@
-const files = {};
+var files = {};
 export function readFileSync(filename, encoding) {
     return files[filename];
 }
-export function writeFileSync(filename, content) {
-    files[filename] = content;
-}
 export function existsSync(filename) {
     return filename in files;
 }
@@ -13,3 +10,7 @@ export function lstatSync(filename) {
         isFile: () => existsSync(filename),
     };
 }
+
+export function writeFiles(new_files) {
+    files = new_files;
+}
