@@ -11,6 +11,7 @@ class Config:
     note: Path
     objects: Path
     xml_ui: Path
+    lua_modules: Path
 
 
 config = Config(
@@ -20,4 +21,5 @@ config = Config(
     note=Path("note.txt"),
     xml_ui=Path("ui.xml"),
     objects=Path("objects"),
+    lua_modules=Path("modules"),
 )
